<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"  
xmlns:marc="http://www.loc.gov/MARC21/slim"
 xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes" />
	<xsl:param name="pdate"></xsl:param>
	
	<xsl:template match="/">
		<marc:collection
			xmlns:marc="http://www.loc.gov/MARC21/slim" 
			xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
			xsi:schemaLocation="http://www.loc.gov/MARC21/slim http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd">
			<marc:record>
				<marc:leader>00000nam  2200000Ia 4500</marc:leader>
				<marc:controlfield tag="007">cr\cn|||||||||</marc:controlfield>
				<marc:controlfield tag="008"><xsl:value-of select="substring($pdate,3)" />s<xsl:value-of select="substring(NBX/YMD/., 1,4)" />\\\\dcu\\\\\\c\\\f000\0\eng\\</marc:controlfield>
				<marc:datafield tag="042" ind1=" " ind2=" ">
					<marc:subfield code="a">nbx</marc:subfield>
				</marc:datafield>
				<xsl:call-template name="title" />
				<xsl:call-template name="source" />
				<xsl:call-template name="Physical_Description" />
				<xsl:call-template name="Notes" />
				<marc:datafield tag="538" ind1=" " ind2=" ">
					<marc:subfield code="a">Mode of access: World Wide Web.</marc:subfield>
				</marc:datafield>
				<xsl:call-template name="language" />
				<xsl:call-template name="rights" />
				<xsl:call-template name="Name_Subject" />
				<xsl:call-template name="Topics_Subject" />
				<xsl:call-template name="Geog_Subject" />
				<xsl:call-template name="Misc_Subject" />
				<xsl:call-template name="creator" />
				<xsl:call-template name="series" />
				<xsl:call-template name="URL" />
			</marc:record>
		</marc:collection>
	</xsl:template>
		<xsl:template name="URL">
		<xsl:for-each select="NBX/URL">
			<marc:datafield tag="856" ind1="4" ind2="1">
				<marc:subfield code="u"><xsl:value-of select="." /></marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	
	<!--HED should not be repeatable -->
	<xsl:template name="title">
		<xsl:for-each select="NBX/HED">
			<marc:datafield tag="245" ind1="1" ind2="0">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="h">[electronic resource]</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Physical_Description">
		<xsl:for-each select="NBX/GRC">
			<xsl:choose>
				<xsl:when test="contains(.,':')">
					<marc:datafield tag="300" ind1=" " ind2=" ">
						<marc:subfield code="a"><xsl:value-of select="substring-before(.,':')" /> : </marc:subfield>
						<marc:subfield code="b"><xsl:value-of select="substring-after(.,':')" />.</marc:subfield>
					</marc:datafield>
				</xsl:when>
				<xsl:otherwise>
					<marc:datafield tag="300" ind1=" " ind2=" ">
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					</marc:datafield>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Genre_Description">
		<xsl:for-each select="NBX/BOD">
			<marc:datafield tag="655" ind1=" " ind2="7">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="2">nbx</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
			
	
		<xsl:template name="creator">
		<!--AUTH_AUT: Personal Name
		    MARC Field: 700 1\-->
		<xsl:for-each select="NBX/AUTH_AUT">
			<marc:datafield tag="700" ind1="1" ind2=" ">
				<xsl:choose>
					<xsl:when test="contains(.,' (')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(.,', ')" />, </marc:subfield>
						<marc:subfield code="d"><xsl:value-of select="substring-after(.,', ')" /></marc:subfield>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
		
		<!--Congressional Personal Name: AUTH_WSR
		    Office of Executive Official: AUTH_EXOA-->
		<xsl:for-each select="NBX/AUTH_WSR | NBX/AUTH_EXOA">
			<marc:datafield tag="700" ind1="1" ind2=" ">
				<xsl:choose>
					<xsl:when test="contains(.,' (')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(.,', ')" />, </marc:subfield>
						<!--There are two levels of commas; a birth and death date and a party affiliation-->
						<xsl:choose>
							<xsl:when test="contains(substring-after(., ', '), ', ')">
								<marc:subfield code="d"><xsl:value-of select="substring-before(substring-after(.,', '), ', ')" />, </marc:subfield>
								<marc:subfield code="c"><xsl:value-of select="substring-after(substring-after(., ', '), ', ')" />.</marc:subfield>
							</xsl:when>
							<xsl:otherwise>
								<marc:subfield code="d"><xsl:value-of select="substring-after(.,', ')" />.</marc:subfield>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
		
	    <!--Geographic Name Creator; ignore for now AUTH_BLC -->
		<!--Office of the President; AUTH_OFPR 
			This information should be represented in one of the 
			two above 700 statements.  As such, move this to a note (500)-->
			
		<!--Corporate Body: AUTH_CBOD; 710 (assume only corporate body is noted, not delimiters needed-->
		<xsl:for-each select="NBX/AUTH_CBOD">
			<marc:datafield tag="710" ind1="2" ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
			</marc:datafield>
		</xsl:for-each>
		
		<!--Congressional Corporate Body: AUTH_CCBD
			Congressional Standing Committee: AUTH_CSTC 
			Conference/Meeting Name: AUTH_CMN
			Executive Office Department: AUTH_EXDA-->

		<xsl:for-each select="NBX/AUTH_CCBD | NBX/AUTH_CSTC  |  NBX/AUTH_EXDA">
			<marc:datafield tag="710" ind1="2" ind2=" ">
				<xsl:choose>
					<xsl:when test="contains(.,'. ')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(., '. ')" />.</marc:subfield>
						<xsl:call-template name="csplit">
							<xsl:with-param name="subfield" select="'b'" />
							<xsl:with-param name="del" select="'. '" />
							<xsl:with-param name="string" select="substring-after(., '. ')" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
	
		<!--Conference/Meeting Name: NBX/AUTH_CMN
				Until I see an example in data, we'll 
				simply stuff it into a 711-->
				
		<xsl:for-each select="NBX/AUTH_CBOD">
			<marc:datafield tag="711" ind1="2" ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Topics_Subject">
		<!--Topical-->
		<xsl:for-each select="NBX/SBJ">
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">nbx</marc:subfield>
				</marc:datafield>
		</xsl:for-each>
		
		<!--Groups of people-->
		<xsl:for-each select="NBX/TERM_SUB">	
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">nbx</marc:subfield>
				</marc:datafield>
		</xsl:for-each>
		
		<!--Aspect-->
		<xsl:for-each select="NBX/TERM_NRRW">	
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">nbx</marc:subfield>
				</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Name_Subject">
	
			<!--AUTH_AUT: Personal Name
		    MARC Field: 700 1\-->
		<xsl:for-each select="NBX/TERM_PNA">
			<marc:datafield tag="600" ind1="1" ind2="7">
				<xsl:choose>
					<xsl:when test="contains(.,' (')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(.,', ')" />, </marc:subfield>
						<marc:subfield code="d"><xsl:value-of select="substring-after(.,', ')" /></marc:subfield>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
		
		<!--Office of Executive Official-->
		<xsl:for-each select="NBX/TERM_EXDO">
			<marc:datafield tag="600" ind1="1" ind2="7">
				<xsl:choose>
					<xsl:when test="contains(.,' (')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(.,', ')" />, </marc:subfield>
						<!--There are two levels of commas; a birth and death date and a party affiliation-->
						<xsl:choose>
							<xsl:when test="contains(substring-after(., ', '), ', ')">
								<marc:subfield code="d"><xsl:value-of select="substring-before(substring-after(.,', '), ', ')" />, </marc:subfield>
								<marc:subfield code="c"><xsl:value-of select="substring-after(substring-after(., ', '), ', ')" />.</marc:subfield>
							</xsl:when>
							<xsl:otherwise>
								<marc:subfield code="d"><xsl:value-of select="substring-after(.,', ')" />.</marc:subfield>
							</xsl:otherwise>
						</xsl:choose>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
		
		<!--Corporate body-->
		<xsl:for-each select="NBX/TERM_CON">
				<marc:datafield tag="610" ind1="2" ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">nbx</marc:subfield>
				</marc:datafield>
		</xsl:for-each>
			
		<!--Congressional Corporate body, Congressional Standing Committee, Executive department name-->
		<xsl:for-each select="NBX/TER3_CON | NBX/TER1_CON | NBX/TERM_EXDN">
			<marc:datafield tag="610" ind1="2" ind2="7">
				<xsl:choose>
					<xsl:when test="contains(.,'. ')">
						<marc:subfield code="a"><xsl:value-of select="substring-before(., '. ')" />.</marc:subfield>
						<xsl:call-template name="csplit">
							<xsl:with-param name="subfield" select="'b'" />
							<xsl:with-param name="del" select="'. '" />
							<xsl:with-param name="string" select="substring-after(., '. ')" />
						</xsl:call-template>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
						<marc:subfield code="2">nbx</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
			</marc:datafield>
		</xsl:for-each>
		
		
		<!--Conference/Meeting Name-->
			
		<xsl:for-each select="NBX/TER2_CON">
			<marc:datafield tag="611" ind1="2" ind2="7">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="2">nbx</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	

	<xsl:template name="Geog_Subject">
		<xsl:for-each select="NBX/TERM_GEO">
			<marc:datafield tag="651" ind1="0" ind2="7">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="2">nbx</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Misc_Subject">
		<!--Uniform Title subjects -->
		<xsl:for-each select="NBX/TERM_UNFM | NBX/TER2_UNFM | NBX/TER3_UNFM | NBX/TER0_UNFM">
			<marc:datafield tag="630" ind1="0" ind2="7">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="2">nbx</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
		
		<!--Try stuff bill number in 657-->
		<xsl:for-each select="NBX/TERM_BNUM">
		    <marc:datafield tag="657" ind1=" " ind2="7">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				<marc:subfield code="2">nbx</marc:subfield>
		    </marc:datafield>
		</xsl:for-each>
	</xsl:template>
	

	<xsl:template name="Notes">
		<!--Memo note about title; if present-->
		<xsl:for-each select="NBX/MEM">
			<marc:datafield tag="500" ind1=" " ind2=" ">
				<!--<xsl:choose>
					<xsl:when test="ends-with(., '.')">-->
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<!--</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>-->
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="series">
		<!--Look for the presence of SESS; should occur only once-->
		<xsl:if test="NBX/SESS">
			<!--<xsl:choose>
				<xsl:when test="NBX/SESSC">
					<marc:datafield tag="500" ind1=" " ind2=" ">
						<marc:subfield code="a">Congressional Session Number: <xsl:value-of select="NBX/SESS" />, Second Session Number: <xsl:value-of select="SESSC" />, Session Volumne Number: <xsl:value-of select="NBX/SVOL" />.</marc:subfield>
					</marc:datafield>
				</xsl:when>
				<xsl:otherwise>
					<marc:datafield tag="500" ind1=" " ind2=" ">
						<marc:subfield code="a">Congressional Session Number: <xsl:value-of select="NBX/SESS" />, Second Session Number: <xsl:value-of select="SESSC" />, Session Volumne Number: <xsl:value-of select="NBX/SVOL" />.</marc:subfield>
					</marc:datafield>
				</xsl:otherwise>
			</xsl:choose>-->
			<marc:datafield tag="810" ind1="1" ind2=" ">
				<marc:subfield code="a">United States.</marc:subfield>
				<marc:subfield code="b">Congress.</marc:subfield>
				<marc:subfield code="n">(<xsl:value-of select="substring-before(NBX/SESS, ' ')" />, <xsl:value-of select="translate(substring-after(NBX/SESS, ', '),'S', 's')" /> :</marc:subfield>
				<marc:subfield code="d"><xsl:value-of select="substring(NBX/YMD/., 1,4)" />)</marc:subfield>
				<xsl:choose>
					<xsl:when test="contains(NBX/SVOL/., 'Senate')">
						<marc:subfield code="b">Senate.</marc:subfield>
					</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="b">House.</marc:subfield>
					</xsl:otherwise>
				</xsl:choose>
				<marc:subfield code="t">Document ;</marc:subfield>
				<marc:subfield code="v">no. <xsl:value-of select="substring-after(NBX/SVOL/., 'Documents ')" /></marc:subfield>
			</marc:datafield>
		</xsl:if>
	</xsl:template>
	<xsl:template name="language">
		<marc:datafield tag="546" ind1=" " ind2=" ">
			<!--<xsl:choose>-->
				<!--<xsl:when test="substring(., '.')">-->
					<marc:subfield code="a"><xsl:value-of select="NBX/LANG" /></marc:subfield>
				<!--</xsl:when>
				<xsl:otherwise>
					<marc:subfield code="a"><xsl:value-of select="NBX/LANG" /></marc:subfield>
				</xsl:otherwise>
			</xsl:choose>-->
		</marc:datafield>
	</xsl:template>
	
	<xsl:template name="source">
		<xsl:if test="NBX/PLOC">
			<marc:datafield tag="260" ind1=" " ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="NBX/PLOC" /> : </marc:subfield>
				<xsl:if test="NBX/SVOL">
					<marc:subfield code="b"><xsl:value-of select="NBX/SVOL" />, </marc:subfield>
				</xsl:if>
				
				<xsl:if test="NBX/YMD">
					<marc:subfield code="c"><xsl:value-of select="substring(NBX/YMD/., 1,4)" />.</marc:subfield>
				</xsl:if>
			</marc:datafield>
		</xsl:if>
		
		<xsl:if test="NBX/PLOC='' and NBX/SVOL">
			<marc:datafield tag="260" ind1=" " ind2=" ">
				<xsl:if test="NBX/SVOL">
					<marc:subfield code="b"><xsl:value-of select="NBX/SVOL" />, </marc:subfield>
				</xsl:if>
				
				<xsl:if test="NBX/YMD">
					<marc:subfield code="c"><xsl:value-of select="substring(NBX/YMD/., 1,4)" />.</marc:subfield>
				</xsl:if>
			</marc:datafield>
		</xsl:if>	
		
		<xsl:if test="NBX/PLOC='' and NBX/SVOL='' and NBX/YMD">
			<marc:datafield tag="260" ind1=" " ind2=" ">
				<xsl:if test="NBX/YMD">
					<marc:subfield code="c"><xsl:value-of select="substring(NBX/YMD/., 1,4)" />.</marc:subfield>
				</xsl:if>
			</marc:datafield>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="rights">
		<xsl:for-each select="NBX/COP">
			<marc:datafield tag="506" ind1=" " ind2=" ">
				<!--<xsl:choose>
					<xsl:when test="ends-with(., '.')">-->
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<!--</xsl:when>
					<xsl:otherwise>
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					</xsl:otherwise>
				</xsl:choose>-->
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	
	<xsl:template name="csplit">
		<xsl:param name="subfield" />
		<xsl:param name="del" />
		<xsl:param name="string" />
		
		<xsl:choose>
			<xsl:when test="contains($string, $del)">
				<marc:subfield>
					<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="substring-before($string, $del)" />.</marc:subfield>
					<xsl:call-template name="csplit">
						<xsl:with-param name="subfield" select="'b'" />
						<xsl:with-param name="del" select="'. '" />
						<xsl:with-param name="string" select="substring-after($string, $del)" />
					</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$string!=''">
					<marc:subfield>
						<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="$string" /></marc:subfield>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="psplit">
		<xsl:param name="subfield" />
		<xsl:param name="del" />
		<xsl:param name="string" />
		
		<xsl:choose>
			<xsl:when test="contains($string, $del)">
				<marc:subfield>
					<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="substring-before($string, $del)" />.</marc:subfield>
					<xsl:call-template name="csplit">
						<xsl:with-param name="subfield" select="'q'" />
						<xsl:with-param name="del" select="'. '" />
						<xsl:with-param name="string" select="substring-after($string, $del)" />
					</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$string!=''">
					<marc:subfield>
						<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="$string" /></marc:subfield>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>